==> gromacs_2021.4.orig.tar.gz: gromacs-2021.4/src/gromacs/mdlib/freeenergyparameters.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2020, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \internal \file
 *
 * \brief Handling of free energy parameters
 *
 * \author Christian Blau <blau@kth.se>
 * \ingroup module_mdlib
 */

#ifndef GMX_MDLIB_FREEENERGYPARAMETERS_H
#define GMX_MDLIB_FREEENERGYPARAMETERS_H

#include <array>

#include "gromacs/mdtypes/md_enums.h"
#include "gromacs/utility/real.h"

struct t_lambda;

namespace gmx
{

/*! \brief Evaluate the current lambdas
 *
 * \param[in] step the current simulation step
 * \param[in] fepvals describing the lambda setup
 * \param[in] currentLambdaState the lambda state to use to set the lambdas, -1 if not set
 * \returns the current lambda-value array
 */
std::array<real, efptNR> currentLambdas(int64_t step, const t_lambda& fepvals, int currentLambdaState);

} // namespace gmx

#endif

==> gromacs_2023.1.orig.tar.gz: gromacs-2023.1/src/gromacs/mdlib/freeenergyparameters.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright 2020- The GROMACS Authors
 * and the project initiators Erik Lindahl, Berk Hess and David van der Spoel.
 * Consult the AUTHORS/COPYING files and https://www.gromacs.org for details.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * https://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at https://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out https://www.gromacs.org.
 */
/*! \internal \file
 *
 * \brief Handling of free energy parameters
 *
 * \author Christian Blau <blau@kth.se>
 * \ingroup module_mdlib
 */

#ifndef GMX_MDLIB_FREEENERGYPARAMETERS_H
#define GMX_MDLIB_FREEENERGYPARAMETERS_H

#include <array>

#include "gromacs/mdtypes/md_enums.h"
#include "gromacs/utility/enumerationhelpers.h"
#include "gromacs/utility/real.h"

struct t_lambda;

namespace gmx
{

/*! \brief Evaluate the current lambdas
 *
 * \param[in] step the current simulation step
 * \param[in] fepvals describing the lambda setup
 * \param[in] currentLambdaState the lambda state to use to set the lambdas, -1 if not set
 * \returns the current lambda-value array
 */
gmx::EnumerationArray<FreeEnergyPerturbationCouplingType, real> currentLambdas(int64_t         step,
                                                                               const t_lambda& fepvals,
                                                                               int currentLambdaState);

} // namespace gmx

#endif
